// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.provider.azure.messageBus.thread;

import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.core.common.util.IServiceAccountJwtClient;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
import org.springframework.context.annotation.Primary;
import org.springframework.context.annotation.Scope;
import org.springframework.context.annotation.ScopedProxyMode;
import org.springframework.stereotype.Component;
import com.google.api.client.util.Strings;

import java.util.HashMap;
import java.util.Map;

@Component
@Scope(value = "ThreadScope", proxyMode = ScopedProxyMode.TARGET_CLASS)
@ConditionalOnExpression("${azure.serviceBus.enabled:true} || ${azure.eventGridToServiceBus.enabled:true}")
@Primary
public class ThreadDpsHeaders extends DpsHeaders {
    @Autowired
    private IServiceAccountJwtClient serviceAccountJwtClient;

    public void setThreadContext(String dataPartitionId, String correlationId, String collaborationId) {
        Map<String, String> headers = new HashMap<>();
        headers.put(DpsHeaders.DATA_PARTITION_ID, dataPartitionId);
        headers.put(DpsHeaders.CORRELATION_ID, correlationId);
        String authToken = this.serviceAccountJwtClient.getIdToken(dataPartitionId);
        headers.put(DpsHeaders.AUTHORIZATION, authToken);
        if (!Strings.isNullOrEmpty(collaborationId))
            headers.put("x-collaboration", collaborationId);
        this.addFromMap(headers);
    }

}


