// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.messageBus;

import com.microsoft.azure.servicebus.Message;
import com.microsoft.azure.servicebus.SubscriptionClient;
import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.MockitoJUnitRunner;
import org.mockito.junit.jupiter.MockitoExtension;
import org.opengroup.osdu.notification.provider.azure.messageBus.MessageHandler;
import org.opengroup.osdu.notification.provider.azure.messageBus.ProcessNotification;

import java.time.Instant;
import java.util.UUID;

import static org.junit.Assert.assertEquals;
import static org.mockito.Mockito.*;

@RunWith(MockitoJUnitRunner.class)
public class MessageHandlerTest {

    private static final String subscriptionName = "TestSubscription";
    private static final String errorMsg = "Error processing notification";
    private static final String appName = "test";

    private MessageHandler messageHandler;

    private ProcessNotification processNotification;

    private Message message;

    private SubscriptionClient subscriptionClient;

    @Before
    public void init() {
        subscriptionClient = mock(SubscriptionClient.class);
        message = mock(Message.class);
        processNotification = mock(ProcessNotification.class);

        when(subscriptionClient.getSubscriptionName()).thenReturn(subscriptionName);

        messageHandler = new MessageHandler(subscriptionClient, processNotification, appName);
    }

    @Test
    public void shouldInvoke_performNotification() throws Exception {
        lenient().doNothing().when(processNotification).performNotification(message, subscriptionName);
        messageHandler.processMessage(message);
        verify(processNotification, times(1)).performNotification(message, subscriptionClient.getSubscriptionName());
    }

    @Test
    public void shouldThrow_WhenProcessNotificationThrowsException() throws Exception {
        doThrow(new Exception(errorMsg)).when(processNotification).performNotification(message, subscriptionName);
        try {
            messageHandler.processMessage(message);
        } catch (Exception e) {
            verify(processNotification, times(1)).performNotification(message, subscriptionName);
            assertEquals(e.getMessage().compareTo(errorMsg), 0);
        }
    }
}
