package org.opengroup.osdu.notification.provider.azure.messageBus.models;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.MockitoAnnotations;
import org.mockito.junit.MockitoJUnitRunner;
import org.springframework.test.util.ReflectionTestUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.junit.Assert.assertEquals;

@RunWith(MockitoJUnitRunner.class)
public class TopicSubscriptionsTest {

    private static final String PARTITION = "opendes";
    private static final String SBTOPICNAME = "recordsTopic";
    private static final String CURRENTSUBSCRIPTION = "test123asjdk";
    private static final String EXISTINGSUBSCRIPTION = "test345asjdk";
    @InjectMocks
    TopicSubscriptions topicSubscriptions;
    private final Map<String, Map<String, List<String>>> existingTopicSubscriptions = new HashMap<>();
    private final Map<String, Map<String, List<String>>> currentTopicSubscriptions = new HashMap<>();

    @Before
    public void setup() {
        Map<String, List<String>> existingSubscriptionMap = new HashMap<>();
        List<String> existingSubscriptionList = new ArrayList<>();
        existingSubscriptionList.add(EXISTINGSUBSCRIPTION);
        existingSubscriptionMap.put(SBTOPICNAME, existingSubscriptionList);
        existingTopicSubscriptions.put(PARTITION, existingSubscriptionMap);

        Map<String, List<String>> currentSubscriptionMap = new HashMap<>();
        List<String> currentSubscriptionList = new ArrayList<>();
        currentSubscriptionList.add(CURRENTSUBSCRIPTION);
        currentSubscriptionMap.put(SBTOPICNAME, currentSubscriptionList);
        currentTopicSubscriptions.put(PARTITION, currentSubscriptionMap);

        MockitoAnnotations.openMocks(TopicSubscriptionsTest.this);
        ReflectionTestUtils.setField(topicSubscriptions, "existingTopicSubscriptions", existingTopicSubscriptions);
        ReflectionTestUtils.setField(topicSubscriptions, "currentTopicSubscriptions", currentTopicSubscriptions);
    }

    @Test
    public void checkIfNewTopicSubscriptionTest_true() {
        boolean actual = topicSubscriptions.checkIfNewTopicSubscription("closedes", SBTOPICNAME, EXISTINGSUBSCRIPTION);
        assertEquals(actual, true);
    }

    @Test
    public void checkIfNewTopicSubscriptionTest_false() {

        boolean actual = topicSubscriptions.checkIfNewTopicSubscription(PARTITION, SBTOPICNAME, EXISTINGSUBSCRIPTION);
        assertEquals(actual, false);
    }

    @Test
    public void updateCurrentTopicSubscriptionsTest() {

        topicSubscriptions.updateCurrentTopicSubscriptions(PARTITION, SBTOPICNAME, "test678");
        List<String> subscriptions = currentTopicSubscriptions.get(PARTITION).get(SBTOPICNAME);
        assertEquals(subscriptions.size(), 2);
        assertEquals(subscriptions.get(1), "test678");

    }

    @Test
    public void clearTopicSubscriptionsTest() {

        topicSubscriptions.clearTopicSubscriptions();
        assertEquals(existingTopicSubscriptions.size(), 1);
        assertEquals(currentTopicSubscriptions.size(), 0);
    }
}
